@@ -1,7 +1,9 @@
 from ctypes import Structure, Union, c_int, c_char_p, POINTER
-from .dll import _bind
+from .dll import _bind, nullfunc
 from .stdinc import SDL_bool, Sint16, Uint8
 from .joystick import SDL_JoystickGUID, SDL_Joystick
+from .rwops import SDL_RWops, SDL_RWFromFile
+
 
 __all__ = ["SDL_GameController", "SDL_CONTROLLER_BINDTYPE_NONE",
            "SDL_CONTROLLER_BINDTYPE_BUTTON", "SDL_CONTROLLER_BINDTYPE_AXIS",
@@ -32,7 +34,8 @@ __all__ = ["SDL_GameController", "SDL_CONTROLLER_BINDTYPE_NONE",
            "SDL_GameControllerGetButtonFromString",
            "SDL_GameControllerGetStringForButton",
            "SDL_GameControllerGetBindForButton", "SDL_GameControllerGetButton",
-           "SDL_GameControllerClose"
+           "SDL_GameControllerClose", "SDL_GameControllerAddMappingsFromFile",
+           "SDL_GameControllerAddMappingsFromRW"
            ]
 
 class SDL_GameController(Structure):
@@ -100,3 +103,6 @@ SDL_GameControllerGetStringForButton = _bind("SDL_GameControllerGetStringForButt
 SDL_GameControllerGetBindForButton = _bind("SDL_GameControllerGetBindForButton", [POINTER(SDL_GameController), SDL_GameControllerButton], SDL_GameControllerButtonBind)
 SDL_GameControllerGetButton = _bind("SDL_GameControllerGetButton", [POINTER(SDL_GameController), SDL_GameControllerButton], Uint8)
 SDL_GameControllerClose = _bind("SDL_GameControllerClose", [POINTER(SDL_GameController)])
+SDL_GameControllerAddMappingsFromRW = _bind("SDL_GameControllerAddMappingsFromRW", [POINTER(SDL_RWops), c_int], c_int, nullfunc)
+SDL_GameControllerAddMappingsFromFile = lambda fname: SDL_GameControllerAddMappingsFromRW(SDL_RWFromFile(fname, "rb"), 1)
+
