@@ -11,14 +11,22 @@ __all__ = ["SDL_HINT_FRAMEBUFFER_ACCELERATION", "SDL_HINT_RENDER_DRIVER",
            "SDL_HINT_XINPUT_ENABLED", "SDL_HINT_GAMECONTROLLERCONFIG",
            "SDL_HINT_ALLOW_TOPMOST", "SDL_HINT_DEFAULT", "SDL_HINT_NORMAL",
            "SDL_HINT_OVERRIDE", "SDL_HINT_JOYSTICK_ALLOW_BACKGROUND_EVENTS",
-           "SDL_HINT_VIDEO_HIGHDPI_DISABLED", "SDL_HINT_ACCEL_AS_JOY",
+           "SDL_HINT_VIDEO_HIGHDPI_DISABLED",
+           "SDL_HINT_ACCELEROMETER_AS_JOYSTICK",
            "SDL_HINT_MAC_CTRL_CLICK_EMULATE_RIGHT_CLICK",
            "SDL_HINT_RENDER_DIRECT3D_THREADSAFE",
            "SDL_HINT_VIDEO_FULLSCREEN_SPACES",
            "SDL_HINT_MOUSE_RELATIVE_MODE_WARP",
+           "SDL_HINT_VIDEO_WIN_D3DCOMPILER", 
+           "SDL_HINT_VIDEO_WINDOW_SHARE_PIXEL_FORMAT",
+           "SDL_HINT_VIDEO_ALLOW_SCREENSAVER",
+           "SDL_HINT_VIDEO_MAC_FULLSCREEN_SPACES",
+           "SDL_HINT_RENDER_DIRECT3D11_DEBUG",
+           "SDL_HINT_WINRT_PRIVACY_POLICY_URL",
+           "SDL_HINT_WINRT_PRIVACY_POLICY_LABEL",
+           "SDL_HINT_WINRT_HANDLE_BACK_BUTTON",
            "SDL_HintPriority", "SDL_SetHintWithPriority", "SDL_SetHint",
-           "SDL_GetHint", "SDL_ClearHints"
-           ]
+           "SDL_GetHint", "SDL_ClearHints" ]
 
 SDL_HINT_FRAMEBUFFER_ACCELERATION = b"SDL_FRAMEBUFFER_ACCELERATION"
 SDL_HINT_RENDER_DRIVER = b"SDL_RENDER_DRIVER"
@@ -33,7 +41,7 @@ SDL_HINT_VIDEO_MINIMIZE_ON_FOCUS_LOSS = b"SDL_VIDEO_MINIMIZE_ON_FOCUS_LOSS"
 SDL_HINT_VIDEO_FULLSCREEN_SPACES = b"SDL_VIDEO_FULLSCREEN_SPACES"
 SDL_HINT_IDLE_TIMER_DISABLED = b"SDL_IOS_IDLE_TIMER_DISABLED"
 SDL_HINT_ORIENTATIONS = b"SDL_IOS_ORIENTATIONS"
-SDL_HINT_ACCEL_AS_JOY = b"SDL_ACCEL_AS_JOY"
+SDL_HINT_ACCELEROMETER_AS_JOYSTICK = b"SDL_ACCELEROMETER_AS_JOYSTICK"
 SDL_HINT_XINPUT_ENABLED = b"SDL_XINPUT_ENABLED"
 SDL_HINT_GAMECONTROLLERCONFIG = b"SDL_GAMECONTROLLERCONFIG"
 SDL_HINT_ALLOW_TOPMOST = b"SDL_ALLOW_TOPMOST"
@@ -43,6 +51,15 @@ SDL_HINT_VIDEO_HIGHDPI_DISABLED = b"SDL_VIDEO_HIGHDPI_DISABLED"
 SDL_HINT_MAC_CTRL_CLICK_EMULATE_RIGHT_CLICK = b"SDL_MAC_CTRL_CLICK_EMULATE_RIGHT_CLICK"
 SDL_HINT_RENDER_DIRECT3D_THREADSAFE = b"SDL_RENDER_DIRECT3D_THREADSAFE"
 SDL_HINT_MOUSE_RELATIVE_MODE_WARP = b"SDL_MOUSE_RELATIVE_MODE_WARP"
+SDL_HINT_VIDEO_WINDOW_SHARE_PIXEL_FORMAT = b"SDL_VIDEO_WINDOW_SHARE_PIXEL_FORMAT"
+SDL_HINT_VIDEO_ALLOW_SCREENSAVER = b"SDL_VIDEO_ALLOW_SCREENSAVER"
+SDL_HINT_VIDEO_MAC_FULLSCREEN_SPACES = b"SDL_VIDEO_MAC_FULLSCREEN_SPACES"
+SDL_HINT_VIDEO_WIN_D3DCOMPILER = b"SDL_VIDEO_WIN_D3DCOMPILER"
+SDL_HINT_RENDER_DIRECT3D11_DEBUG = b"SDL_RENDER_DIRECT3D11_DEBUG"
+SDL_HINT_WINRT_PRIVACY_POLICY_URL = b"SDL_WINRT_PRIVACY_POLICY_URL"
+SDL_HINT_WINRT_PRIVACY_POLICY_LABEL = b"SDL_WINRT_PRIVACY_POLICY_LABEL"
+SDL_HINT_WINRT_HANDLE_BACK_BUTTON = b"SDL_WINRT_HANDLE_BACK_BUTTON"
+
 
 SDL_HINT_DEFAULT = 0
 SDL_HINT_NORMAL = 1
